============
1.24.1.post2
============

-------
General
-------

****
Bugs
****

- Transfers: Messages created by core/transfer use the wrong type and state `#4251 <https://github.com/rucio/rucio/issues/4251>`_
